ethereum

package
v0.0.0-...-967d326 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2019 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Agent

type Agent struct {
	// contains filtered or unexported fields
}

Agent (ethereum.Agent) implements election.BlockchainAgent in the case of ethereum

func (*Agent) NotifyOnBatchDone

func (e *Agent) NotifyOnBatchDone(ethereum.Transaction)

NotifyOnBatchDone implements blockchain.Notification and verifies if a transaction indicate that an aggregation step has been completed

func (*Agent) NotifyOnNewBatch

func (e *Agent) NotifyOnNewBatch(ethereum.Transaction)

NotifyOnNewBatch implements blockchain.Notification and verifies if the transaction triggers a new batch and callback the Participant if so

Jump to